@@ -76,8 +76,8 @@ class AmphoraProviderDriver(driver_base.ProviderDriver):
 
     def _validate_pool_algorithm(self, pool):
         if pool.lb_algorithm not in AMPHORA_SUPPORTED_LB_ALGORITHMS:
-            msg = ('Amphora provider does not support %s algorithm.'
-                   % pool.lb_algorithm)
+            msg = (f'Amphora provider does not support {pool.lb_algorithm} '
+                   f'algorithm.')
             raise exceptions.UnsupportedOptionError(
                 user_fault_string=msg,
                 operator_fault_string=msg)
@@ -473,9 +473,9 @@ class AmphoraProviderDriver(driver_base.ProviderDriver):
         except js_exceptions.ValidationError as e:
             error_object = ''
             if e.relative_path:
-                error_object = '{} '.format(e.relative_path[0])
+                error_object = f'{e.relative_path[0]} '
             raise exceptions.UnsupportedOptionError(
-                user_fault_string='{0}{1}'.format(error_object, e.message),
+                user_fault_string=f'{error_object}{e.message}',
                 operator_fault_string=str(e))
         except Exception as e:
             raise exceptions.DriverError(
@@ -559,9 +559,9 @@ class AmphoraProviderDriver(driver_base.ProviderDriver):
         except js_exceptions.ValidationError as e:
             error_object = ''
             if e.relative_path:
-                error_object = '{} '.format(e.relative_path[0])
+                error_object = f'{e.relative_path[0]} '
             raise exceptions.UnsupportedOptionError(
-                user_fault_string='{0}{1}'.format(error_object, e.message),
+                user_fault_string=f'{error_object}{e.message}',
                 operator_fault_string=str(e))
         except Exception as e:
             raise exceptions.DriverError(
