@@ -378,7 +378,7 @@ class Member(BaseDataModel):
                  subnet_id=None, operating_status=None, pool=None,
                  created_at=None, updated_at=None, provisioning_status=None,
                  name=None, monitor_address=None, monitor_port=None,
-                 tags=None):
+                 tags=None, vnic_type=None):
         self.id = id
         self.project_id = project_id
         self.pool_id = pool_id
@@ -397,6 +397,7 @@ class Member(BaseDataModel):
         self.monitor_address = monitor_address
         self.monitor_port = monitor_port
         self.tags = tags
+        self.vnic_type = vnic_type
 
     def delete(self):
         for mem in self.pool.members:
@@ -558,7 +559,7 @@ class Vip(BaseDataModel):
     def __init__(self, load_balancer_id=None, ip_address=None,
                  subnet_id=None, network_id=None, port_id=None,
                  load_balancer=None, qos_policy_id=None, octavia_owned=None,
-                 vnic_type=None):
+                 vnic_type=None, sg_ids=None):
         self.load_balancer_id = load_balancer_id
         self.ip_address = ip_address
         self.subnet_id = subnet_id
@@ -568,6 +569,18 @@ class Vip(BaseDataModel):
         self.qos_policy_id = qos_policy_id
         self.octavia_owned = octavia_owned
         self.vnic_type = vnic_type
+        self.sg_ids = sg_ids or []
+
+    def to_dict(self, **kwargs):
+        ret = super().to_dict(**kwargs)
+        if kwargs.get('recurse') is not True:
+            # NOTE(gthiemonge) we need to return the associated SG IDs but as
+            # sg_ids is a list, they are only added with recurse=True, which
+            # does a full recursion on the Vip, adding the associated
+            # LoadBalancer, its Listeners, etc...
+            # Adding it directly here avoids unnecessary recursion
+            ret[constants.SG_IDS] = self.sg_ids
+        return ret
 
 
 class AdditionalVip(BaseDataModel):
@@ -886,3 +899,20 @@ class ListenerCidr(BaseDataModel):
     # object. Otherwise we recurse down the "ghost" listener object.
     def to_dict(self, **kwargs):
         return {'cidr': self.cidr, 'listener_id': self.listener_id}
+
+
+class VipSecurityGroup(BaseDataModel):
+    def __init__(self, load_balancer_id: str = None, sg_id: str = None):
+        self.load_balancer_id = load_balancer_id
+        self.sg_id = sg_id
+
+
+class AmphoraMemberPort(BaseDataModel):
+
+    def __init__(self, port_id=None, amphora_id=None, network_id=None,
+                 created_at=None, updated_at=None):
+        self.port_id = port_id
+        self.amphora_id = amphora_id
+        self.network_id = network_id
+        self.created_at = created_at
+        self.updated_at = updated_at
