@@ -11,15 +11,12 @@
 #    under the License.
 
 """Policy Engine For Octavia."""
-
-import sys
-
 from oslo_config import cfg
 from oslo_log import log as logging
+from oslo_policy import opts
 from oslo_policy import policy as oslo_policy
 from oslo_utils import excutils
 
-from octavia.common import config
 from octavia.common import exceptions
 from octavia import policies
 
@@ -28,6 +25,13 @@ LOG = logging.getLogger(__name__)
 OCTAVIA_POLICY = None
 
 
+# TODO(gmann): Remove setting the default value of config policy_file
+# once oslo_policy change the default value to 'policy.yaml'.
+# https://github.com/openstack/oslo.policy/blob/a626ad12fe5a3abd49d70e3e5b95589d279ab578/oslo_policy/opts.py#L49
+DEFAULT_POLICY_FILE = 'policy.yaml'
+opts.set_defaults(cfg.CONF, DEFAULT_POLICY_FILE)
+
+
 def get_enforcer():
     global OCTAVIA_POLICY
     if OCTAVIA_POLICY is None:
@@ -67,8 +71,8 @@ class Policy(oslo_policy.Enforcer):
                               rules from config file.
         """
 
-        super(Policy, self).__init__(conf, policy_file, rules, default_rule,
-                                     use_conf, overwrite)
+        super().__init__(conf, policy_file, rules, default_rule, use_conf,
+                         overwrite)
 
         self.register_defaults(policies.list_rules())
 
@@ -111,7 +115,7 @@ class Policy(oslo_policy.Enforcer):
             exc = exceptions.PolicyForbidden
 
         try:
-            return super(Policy, self).authorize(
+            return super().authorize(
                 action, target, credentials, do_raise=do_raise, exc=exc)
         except oslo_policy.PolicyNotRegistered:
             with excutils.save_and_reraise_exception():
@@ -122,13 +126,22 @@ class Policy(oslo_policy.Enforcer):
                 LOG.debug('Policy check for %(action)s failed with '
                           'credentials %(credentials)s',
                           {'action': action, 'credentials': credentials})
+        return None
 
     def check_is_admin(self, context):
         """Does roles contains 'admin' role according to policy setting.
 
         """
         credentials = context.to_dict()
-        return self.enforce('context_is_admin', credentials, credentials)
+        result = False
+        try:
+            result = self.enforce('context_is_admin', credentials, credentials)
+        except oslo_policy.InvalidScope as e:
+            # This will happen if the token being used is system scoped
+            # when scope checking is enabled.
+            LOG.warning(str(e))
+            return False
+        return result
 
     def get_rules(self):
         return self.rules
@@ -143,7 +156,7 @@ class IsAdminCheck(oslo_policy.Check):
 
         self.expected = match.lower() == 'true'
 
-        super(IsAdminCheck, self).__init__(kind, str(self.expected))
+        super().__init__(kind, str(self.expected))
 
     def __call__(self, target, creds, enforcer):
         """Determine whether is_admin matches the requested value."""
@@ -153,14 +166,4 @@ class IsAdminCheck(oslo_policy.Check):
 
 # This is used for the oslopolicy-policy-generator tool
 def get_no_context_enforcer():
-
-    # oslo.config needs access to the --config-dir and --config-file
-    # command line args
-    filtered_args = ['--config-dir', '--config-file']
-    # Start at 1 because cfg.CONF expects the equivalent of sys.argv[1:]
-    conf_args = [arg for idx, arg in enumerate(sys.argv[1:])
-                 if (arg in filtered_args or
-                     sys.argv[idx] in filtered_args)]
-
-    config.init(conf_args)
     return Policy()
