@@ -29,7 +29,7 @@ down_revision = '4fe8240425b4'
 
 
 def upgrade():
-    op.add_column(u'amphora',
-                  sa.Column(u'vrrp_port_id', sa.String(36), nullable=True))
-    op.add_column(u'amphora',
-                  sa.Column(u'ha_port_id', sa.String(36), nullable=True))
+    op.add_column('amphora',
+                  sa.Column('vrrp_port_id', sa.String(36), nullable=True))
+    op.add_column('amphora',
+                  sa.Column('ha_port_id', sa.String(36), nullable=True))
