@@ -13,10 +13,16 @@
 #    under the License.
 
 import abc
+import typing
 
 from octavia.common import constants
+from octavia.common import data_models
 from octavia.common import exceptions
 
+if typing.TYPE_CHECKING:
+    from octavia.common import context
+    import octavia.network.data_models as n_data_models
+
 
 class NetworkException(exceptions.OctaviaException):
     pass
@@ -94,7 +100,8 @@ class AbstractNetworkDriver(metaclass=abc.ABCMeta):
     """
 
     @abc.abstractmethod
-    def allocate_vip(self, load_balancer):
+    def allocate_vip(self, load_balancer: data_models.LoadBalancer) -> (
+            tuple[data_models.Vip, list[data_models.AdditionalVip]]):
         """Allocates a virtual ip.
 
         Reserves it for later use as the frontend connection of a load
@@ -156,16 +163,6 @@ class AbstractNetworkDriver(metaclass=abc.ABCMeta):
         :raises: UnplugVIPException, PluggedVIPNotFound
         """
 
-    @abc.abstractmethod
-    def plug_network(self, compute_id, network_id):
-        """Connects an existing amphora to an existing network.
-
-        :param compute_id: id of an amphora in the compute service
-        :param network_id: id of a network
-        :return: octavia.network.data_models.Interface instance
-        :raises: PlugNetworkException, AmphoraNotFound, NetworkNotFound
-        """
-
     @abc.abstractmethod
     def unplug_network(self, compute_id, network_id):
         """Disconnects an existing amphora from an existing network.
@@ -294,13 +291,25 @@ class AbstractNetworkDriver(metaclass=abc.ABCMeta):
 
     @abc.abstractmethod
     def get_security_group(self, sg_name):
-        """Retrieves the security group by it's name.
+        """Retrieves the security group by its name.
 
         :param sg_name: The security group name.
         :return: octavia.network.data_models.SecurityGroup, None if not enabled
         :raises: NetworkException, SecurityGroupNotFound
         """
 
+    @abc.abstractmethod
+    def get_security_group_by_id(self, sg_id: str,
+                                 context: 'context.RequestContext' = None) -> (
+            'n_data_models.SecurityGroup'):
+        """Retrieves the security group by its id.
+
+        :param sg_id: The security group ID.
+        :param context: A request context
+        :return: octavia.network.data_models.SecurityGroup, None if not enabled
+        :raises: NetworkException, SecurityGroupNotFound
+        """
+
     @abc.abstractmethod
     def failover_preparation(self, amphora):
         """Prepare an amphora for failover.
@@ -349,6 +358,14 @@ class AbstractNetworkDriver(metaclass=abc.ABCMeta):
         :param vip: The VIP to plug
         """
 
+    @abc.abstractmethod
+    def update_aap_port_sg(self, load_balancer: data_models.LoadBalancer,
+                           amphora: data_models.Amphora,
+                           vip: data_models.Vip):
+        """Updates the security group of the AAP port of an amphora
+
+        """
+
     @abc.abstractmethod
     def plug_aap_port(self, load_balancer, vip, amphora, subnet):
         """Plugs the AAP port to the amp
