@@ -12,6 +12,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import typing
+
 from openstack.connection import Connection
 import openstack.exceptions as os_exceptions
 from openstack.network.v2._proxy import Proxy
@@ -25,6 +27,9 @@ from octavia.network import base
 from octavia.network import data_models as network_models
 from octavia.network.drivers.neutron import utils
 
+if typing.TYPE_CHECKING:
+    from octavia.common import context
+
 LOG = logging.getLogger(__name__)
 DNS_INT_EXT_ALIAS = 'dns-integration'
 SEC_GRP_EXT_ALIAS = 'security-group'
@@ -76,21 +81,22 @@ class BaseNeutronDriver(base.AbstractNetworkDriver):
                 fixed_ip = port_fixed_ip
             else:
                 additional_ips.append(port_fixed_ip)
+        kwargs = {
+            'ip_address': None,
+            'subnet_id': None
+        }
         if fixed_ip:
-            primary_vip = data_models.Vip(ip_address=fixed_ip.ip_address,
-                                          subnet_id=fixed_ip.subnet_id,
-                                          network_id=port.network_id,
-                                          port_id=port.id,
-                                          load_balancer=load_balancer,
-                                          load_balancer_id=load_balancer.id,
-                                          octavia_owned=octavia_owned)
-        else:
-            primary_vip = data_models.Vip(ip_address=None, subnet_id=None,
-                                          network_id=port.network_id,
-                                          port_id=port.id,
-                                          load_balancer=load_balancer,
-                                          load_balancer_id=load_balancer.id,
-                                          octavia_owned=octavia_owned)
+            kwargs['ip_address'] = fixed_ip.ip_address
+            kwargs['subnet_id'] = fixed_ip.subnet_id
+
+        primary_vip = data_models.Vip(
+            network_id=port.network_id,
+            port_id=port.id,
+            load_balancer=load_balancer,
+            load_balancer_id=load_balancer.id,
+            octavia_owned=octavia_owned,
+            sg_ids=load_balancer.vip.sg_ids,
+            **kwargs)
         additional_vips = [
             data_models.AdditionalVip(
                 ip_address=add_fixed_ip.ip_address,
@@ -123,11 +129,12 @@ class BaseNeutronDriver(base.AbstractNetworkDriver):
         self.network_proxy.update_port(port_id,
                                        allowed_address_pairs=aap)
 
-    def _add_security_group_to_port(self, sec_grp_id, port_id):
+    def _update_security_groups(self, sec_grp_ids: list[str],
+                                port_id: str):
         # Note: Neutron accepts the SG even if it already exists
         try:
             self.network_proxy.update_port(
-                port_id, security_groups=[sec_grp_id])
+                port_id, security_groups=sec_grp_ids)
         except os_exceptions.NotFoundException as e:
             raise base.PortNotFound(str(e))
         except Exception as e:
@@ -252,6 +259,11 @@ class BaseNeutronDriver(base.AbstractNetworkDriver):
     def get_port(self, port_id, context=None):
         return self._get_resource('port', port_id, context=context)
 
+    def get_security_group_by_id(self, sg_id: str,
+                                 context: 'context.RequestContext' = None) -> (
+            'network_models.SecurityGroup'):
+        return self._get_resource('security_group', sg_id, context=context)
+
     def get_network_by_name(self, network_name):
         return self._get_resources_by_filters(
             'network', unique_item=True, name=network_name)
