@@ -50,6 +50,9 @@ class SampleDriverDataModels:
         self.pool_ca_container_ref = uuidutils.generate_uuid()
         self.pool_crl_container_ref = uuidutils.generate_uuid()
 
+        self.vip_sg_ids = [uuidutils.generate_uuid(),
+                           uuidutils.generate_uuid()]
+
         self.pool1_id = uuidutils.generate_uuid()
         self.pool2_id = uuidutils.generate_uuid()
 
@@ -145,7 +148,8 @@ class SampleDriverDataModels:
             constants.CREATED_AT: self.created_at,
             constants.UPDATED_AT: self.updated_at,
             lib_consts.MONITOR_ADDRESS: '192.0.2.26',
-            lib_consts.MONITOR_PORT: 81}
+            lib_consts.MONITOR_PORT: 81,
+            lib_consts.VNIC_TYPE: lib_consts.VNIC_TYPE_NORMAL}
 
         self.test_member1_dict.update(self._common_test_dict)
 
@@ -154,6 +158,8 @@ class SampleDriverDataModels:
         self.test_member2_dict[constants.IP_ADDRESS] = '192.0.2.17'
         self.test_member2_dict[lib_consts.MONITOR_ADDRESS] = '192.0.2.27'
         self.test_member2_dict[lib_consts.NAME] = 'member2'
+        self.test_member2_dict[
+            lib_consts.VNIC_TYPE] = lib_consts.VNIC_TYPE_DIRECT
 
         self.test_member3_dict = copy.deepcopy(self.test_member1_dict)
         self.test_member3_dict[lib_consts.ID] = self.member3_id
@@ -182,24 +188,28 @@ class SampleDriverDataModels:
         self.db_pool1_members = [self.db_member1, self.db_member2]
         self.db_pool2_members = [self.db_member3, self.db_member4]
 
-        self.provider_member1_dict = {lib_consts.ADDRESS: '192.0.2.16',
-                                      lib_consts.ADMIN_STATE_UP: True,
-                                      lib_consts.MEMBER_ID: self.member1_id,
-                                      lib_consts.MONITOR_ADDRESS: '192.0.2.26',
-                                      lib_consts.MONITOR_PORT: 81,
-                                      lib_consts.NAME: 'member1',
-                                      lib_consts.POOL_ID: self.pool1_id,
-                                      lib_consts.PROJECT_ID: self.project_id,
-                                      lib_consts.PROTOCOL_PORT: 80,
-                                      lib_consts.SUBNET_ID: self.subnet_id,
-                                      lib_consts.WEIGHT: 0,
-                                      lib_consts.BACKUP: False}
+        self.provider_member1_dict = {
+            lib_consts.ADDRESS: '192.0.2.16',
+            lib_consts.ADMIN_STATE_UP: True,
+            lib_consts.MEMBER_ID: self.member1_id,
+            lib_consts.MONITOR_ADDRESS: '192.0.2.26',
+            lib_consts.MONITOR_PORT: 81,
+            lib_consts.NAME: 'member1',
+            lib_consts.POOL_ID: self.pool1_id,
+            lib_consts.PROJECT_ID: self.project_id,
+            lib_consts.PROTOCOL_PORT: 80,
+            lib_consts.SUBNET_ID: self.subnet_id,
+            lib_consts.WEIGHT: 0,
+            lib_consts.BACKUP: False,
+            lib_consts.VNIC_TYPE: lib_consts.VNIC_TYPE_NORMAL}
 
         self.provider_member2_dict = copy.deepcopy(self.provider_member1_dict)
         self.provider_member2_dict[lib_consts.MEMBER_ID] = self.member2_id
         self.provider_member2_dict[lib_consts.ADDRESS] = '192.0.2.17'
         self.provider_member2_dict[lib_consts.MONITOR_ADDRESS] = '192.0.2.27'
         self.provider_member2_dict[lib_consts.NAME] = 'member2'
+        self.provider_member2_dict[
+            lib_consts.VNIC_TYPE] = lib_consts.VNIC_TYPE_DIRECT
 
         self.provider_member3_dict = copy.deepcopy(self.provider_member1_dict)
         self.provider_member3_dict[lib_consts.MEMBER_ID] = self.member3_id
@@ -600,6 +610,7 @@ class SampleDriverDataModels:
                               constants.PORT_ID: self.port_id,
                               lib_consts.SUBNET_ID: self.subnet_id,
                               constants.QOS_POLICY_ID: self.qos_policy_id,
+                              constants.SG_IDS: self.vip_sg_ids,
                               constants.OCTAVIA_OWNED: None}
 
         self.provider_vip_dict = {
@@ -608,6 +619,7 @@ class SampleDriverDataModels:
             lib_consts.VIP_PORT_ID: self.port_id,
             lib_consts.VIP_SUBNET_ID: self.subnet_id,
             lib_consts.VIP_QOS_POLICY_ID: self.qos_policy_id,
+            lib_consts.VIP_SG_IDS: self.vip_sg_ids,
             constants.OCTAVIA_OWNED: None}
 
         self.test_additional_vip_dict = {
@@ -627,7 +639,8 @@ class SampleDriverDataModels:
             network_id=self.network_id,
             port_id=self.port_id,
             subnet_id=self.subnet_id,
-            qos_policy_id=self.qos_policy_id)
+            qos_policy_id=self.qos_policy_id,
+            sg_ids=self.vip_sg_ids)
 
         self.db_additional_vip = data_models.AdditionalVip(
             ip_address=self.ip_address2,
