@@ -191,9 +191,9 @@ class TestAvailabilityZoneProfiles(base.BaseAPITest):
                 'fields': ['id', constants.PROVIDER_NAME]}
         ).json.get(self.root_tag)
         self.assertEqual(azp.get('id'), response.get('id'))
-        self.assertIn(u'id', response)
+        self.assertIn('id', response)
         self.assertIn(constants.PROVIDER_NAME, response)
-        self.assertNotIn(u'name', response)
+        self.assertNotIn('name', response)
         self.assertNotIn(constants.AVAILABILITY_ZONE_DATA, response)
 
     def test_get_authorized(self):
@@ -243,15 +243,15 @@ class TestAvailabilityZoneProfiles(base.BaseAPITest):
     def test_get_all(self):
         fp1 = self.create_availability_zone_profile(
             'test1', 'noop_driver', '{"compute_zone": "my_az_1"}')
-        ref_fp_1 = {u'availability_zone_data': u'{"compute_zone": "my_az_1"}',
-                    u'id': fp1.get('id'), u'name': u'test1',
-                    constants.PROVIDER_NAME: u'noop_driver'}
+        ref_fp_1 = {'availability_zone_data': '{"compute_zone": "my_az_1"}',
+                    'id': fp1.get('id'), 'name': 'test1',
+                    constants.PROVIDER_NAME: 'noop_driver'}
         self.assertTrue(uuidutils.is_uuid_like(fp1.get('id')))
         fp2 = self.create_availability_zone_profile(
             'test2', 'noop_driver-alt', '{"compute_zone": "my_az_1"}')
-        ref_fp_2 = {u'availability_zone_data': u'{"compute_zone": "my_az_1"}',
-                    u'id': fp2.get('id'), u'name': u'test2',
-                    constants.PROVIDER_NAME: u'noop_driver-alt'}
+        ref_fp_2 = {'availability_zone_data': '{"compute_zone": "my_az_1"}',
+                    'id': fp2.get('id'), 'name': 'test2',
+                    constants.PROVIDER_NAME: 'noop_driver-alt'}
         self.assertTrue(uuidutils.is_uuid_like(fp2.get('id')))
 
         response = self.get(self.AZPS_PATH)
@@ -273,8 +273,8 @@ class TestAvailabilityZoneProfiles(base.BaseAPITest):
         api_list = response.json.get(self.root_tag_list)
         self.assertEqual(2, len(api_list))
         for profile in api_list:
-            self.assertIn(u'id', profile)
-            self.assertIn(u'name', profile)
+            self.assertIn('id', profile)
+            self.assertIn('name', profile)
             self.assertNotIn(constants.PROVIDER_NAME, profile)
             self.assertNotIn(constants.AVAILABILITY_ZONE_DATA, profile)
 
@@ -375,8 +375,7 @@ class TestAvailabilityZoneProfiles(base.BaseAPITest):
     def _test_update_param_none(self, param_name):
         azp = self.create_availability_zone_profile(
             'test_profile', 'noop_driver', '{"x": "y"}')
-        expect_error_msg = ("None is not a valid option for %s" %
-                            param_name)
+        expect_error_msg = f"None is not a valid option for {param_name}"
         body = self._build_body({param_name: None})
         response = self.put(self.AZP_PATH.format(azp_id=azp.get('id')), body,
                             status=400)
@@ -513,7 +512,7 @@ class TestAvailabilityZoneProfiles(base.BaseAPITest):
         self.delete(self.AZP_PATH.format(azp_id=azp.get('id')))
         response = self.get(self.AZP_PATH.format(
             azp_id=azp.get('id')), status=404)
-        err_msg = "Availability Zone Profile %s not found." % azp.get('id')
+        err_msg = f"Availability Zone Profile {azp.get('id')} not found."
         self.assertEqual(err_msg, response.json.get('faultstring'))
 
     def test_delete_deleted_id(self):
@@ -560,7 +559,7 @@ class TestAvailabilityZoneProfiles(base.BaseAPITest):
         self.conf.config(group='api_settings', auth_strategy=auth_strategy)
         response = self.get(self.AZP_PATH.format(
             azp_id=azp.get('id')), status=404)
-        err_msg = "Availability Zone Profile %s not found." % azp.get('id')
+        err_msg = f"Availability Zone Profile {azp.get('id')} not found."
         self.assertEqual(err_msg, response.json.get('faultstring'))
 
     def test_delete_not_authorized(self):
