@@ -189,9 +189,9 @@ class TestFlavorProfiles(base.BaseAPITest):
                 'fields': ['id', constants.PROVIDER_NAME]}
         ).json.get(self.root_tag)
         self.assertEqual(fp.get('id'), response.get('id'))
-        self.assertIn(u'id', response)
+        self.assertIn('id', response)
         self.assertIn(constants.PROVIDER_NAME, response)
-        self.assertNotIn(u'name', response)
+        self.assertNotIn('name', response)
         self.assertNotIn(constants.FLAVOR_DATA, response)
 
     def test_get_authorized(self):
@@ -241,15 +241,15 @@ class TestFlavorProfiles(base.BaseAPITest):
     def test_get_all(self):
         fp1 = self.create_flavor_profile('test1', 'noop_driver',
                                          '{"image": "ubuntu"}')
-        ref_fp_1 = {u'flavor_data': u'{"image": "ubuntu"}',
-                    u'id': fp1.get('id'), u'name': u'test1',
-                    constants.PROVIDER_NAME: u'noop_driver'}
+        ref_fp_1 = {'flavor_data': '{"image": "ubuntu"}',
+                    'id': fp1.get('id'), 'name': 'test1',
+                    constants.PROVIDER_NAME: 'noop_driver'}
         self.assertTrue(uuidutils.is_uuid_like(fp1.get('id')))
         fp2 = self.create_flavor_profile('test2', 'noop_driver-alt',
                                          '{"image": "ubuntu"}')
-        ref_fp_2 = {u'flavor_data': u'{"image": "ubuntu"}',
-                    u'id': fp2.get('id'), u'name': u'test2',
-                    constants.PROVIDER_NAME: u'noop_driver-alt'}
+        ref_fp_2 = {'flavor_data': '{"image": "ubuntu"}',
+                    'id': fp2.get('id'), 'name': 'test2',
+                    constants.PROVIDER_NAME: 'noop_driver-alt'}
         self.assertTrue(uuidutils.is_uuid_like(fp2.get('id')))
 
         response = self.get(self.FPS_PATH)
@@ -271,8 +271,8 @@ class TestFlavorProfiles(base.BaseAPITest):
         api_list = response.json.get(self.root_tag_list)
         self.assertEqual(2, len(api_list))
         for profile in api_list:
-            self.assertIn(u'id', profile)
-            self.assertIn(u'name', profile)
+            self.assertIn('id', profile)
+            self.assertIn('name', profile)
             self.assertNotIn(constants.PROVIDER_NAME, profile)
             self.assertNotIn(constants.FLAVOR_DATA, profile)
 
@@ -373,8 +373,7 @@ class TestFlavorProfiles(base.BaseAPITest):
     def _test_update_param_none(self, param_name):
         fp = self.create_flavor_profile('test_profile', 'noop_driver',
                                         '{"x": "y"}')
-        expect_error_msg = ("None is not a valid option for %s" %
-                            param_name)
+        expect_error_msg = f"None is not a valid option for {param_name}"
         body = self._build_body({param_name: None})
         response = self.put(self.FP_PATH.format(fp_id=fp.get('id')), body,
                             status=400)
@@ -465,8 +464,8 @@ class TestFlavorProfiles(base.BaseAPITest):
         body = self._build_body(update_data)
         response = self.put(self.FP_PATH.format(fp_id=fp.get('id')), body,
                             status=409)
-        err_msg = ("Flavor profile {} is in use and cannot be "
-                   "modified.".format(fp.get('id')))
+        err_msg = (f"Flavor profile {fp.get('id')} is in use and cannot be "
+                   f"modified.")
         self.assertEqual(err_msg, response.json.get('faultstring'))
         response = self.get(
             self.FP_PATH.format(fp_id=fp.get('id'))).json.get(self.root_tag)
@@ -480,8 +479,8 @@ class TestFlavorProfiles(base.BaseAPITest):
         body = self._build_body(update_data)
         response = self.put(self.FP_PATH.format(fp_id=fp.get('id')), body,
                             status=409)
-        err_msg = ("Flavor profile {} is in use and cannot be "
-                   "modified.".format(fp.get('id')))
+        err_msg = (f"Flavor profile {fp.get('id')} is in use and cannot "
+                   f"be modified.")
         self.assertEqual(err_msg, response.json.get('faultstring'))
         response = self.get(
             self.FP_PATH.format(fp_id=fp.get('id'))).json.get(self.root_tag)
@@ -506,7 +505,7 @@ class TestFlavorProfiles(base.BaseAPITest):
         self.delete(self.FP_PATH.format(fp_id=fp.get('id')))
         response = self.get(self.FP_PATH.format(
             fp_id=fp.get('id')), status=404)
-        err_msg = "Flavor Profile %s not found." % fp.get('id')
+        err_msg = f"Flavor Profile {fp.get('id')} not found."
         self.assertEqual(err_msg, response.json.get('faultstring'))
 
     def test_delete_deleted_id(self):
@@ -552,7 +551,7 @@ class TestFlavorProfiles(base.BaseAPITest):
         self.conf.config(group='api_settings', auth_strategy=auth_strategy)
         response = self.get(self.FP_PATH.format(
             fp_id=fp.get('id')), status=404)
-        err_msg = "Flavor Profile %s not found." % fp.get('id')
+        err_msg = f"Flavor Profile {fp.get('id')} not found."
         self.assertEqual(err_msg, response.json.get('faultstring'))
 
     def test_delete_not_authorized(self):
@@ -578,8 +577,8 @@ class TestFlavorProfiles(base.BaseAPITest):
         self.create_flavor('name1', 'description', fp.get('id'), True)
         response = self.delete(self.FP_PATH.format(fp_id=fp.get('id')),
                                status=409)
-        err_msg = ("Flavor profile {} is in use and cannot be "
-                   "modified.".format(fp.get('id')))
+        err_msg = (f"Flavor profile {fp.get('id')} is in use and cannot be "
+                   f"modified.")
         self.assertEqual(err_msg, response.json.get('faultstring'))
         response = self.get(
             self.FP_PATH.format(fp_id=fp.get('id'))).json.get(self.root_tag)
