@@ -298,7 +298,7 @@ class TestQuotas(base.BaseAPITest):
                 'is_admin_project': True,
                 'service_project_domain_id': None,
                 'service_project_id': None,
-                'roles': ['load-balancer_global_observer'],
+                'roles': ['admin'],
                 'user_id': None,
                 'is_admin': False,
                 'service_user_domain_id': None,
@@ -345,7 +345,7 @@ class TestQuotas(base.BaseAPITest):
                 'is_admin_project': True,
                 'service_project_domain_id': None,
                 'service_project_id': None,
-                'roles': ['load-balancer_quota_admin'],
+                'roles': ['admin'],
                 'user_id': None,
                 'is_admin': False,
                 'service_user_domain_id': None,
@@ -394,7 +394,7 @@ class TestQuotas(base.BaseAPITest):
                 'is_admin_project': True,
                 'service_project_domain_id': None,
                 'service_project_id': None,
-                'roles': ['load-balancer_member'],
+                'roles': ['load-balancer_member', 'member'],
                 'user_id': None,
                 'is_admin': False,
                 'service_user_domain_id': None,
@@ -440,7 +440,7 @@ class TestQuotas(base.BaseAPITest):
                 'is_admin_project': True,
                 'service_project_domain_id': None,
                 'service_project_id': None,
-                'roles': ['load-balancer_observer'],
+                'roles': ['load-balancer_observer', 'reader'],
                 'user_id': None,
                 'is_admin': False,
                 'service_user_domain_id': None,
@@ -480,18 +480,15 @@ class TestQuotas(base.BaseAPITest):
         self._assert_quotas_equal(quotas, quota2)
 
     def test_get_Authorized_member(self):
-        self._test_get_Authorized('load-balancer_member')
+        self._test_get_Authorized(['load-balancer_member', 'member'])
 
     def test_get_Authorized_observer(self):
-        self._test_get_Authorized('load-balancer_observer')
-
-    def test_get_Authorized_global_observer(self):
-        self._test_get_Authorized('load-balancer_global_observer')
+        self._test_get_Authorized(['load-balancer_observer', 'reader'])
 
     def test_get_Authorized_quota_admin(self):
-        self._test_get_Authorized('load-balancer_quota_admin')
+        self._test_get_Authorized(['admin'])
 
-    def _test_get_Authorized(self, role):
+    def _test_get_Authorized(self, roles):
         project1_id = uuidutils.generate_uuid()
         quota1 = self.create_quota(
             project_id=project1_id, lb_quota=1, member_quota=1
@@ -509,7 +506,7 @@ class TestQuotas(base.BaseAPITest):
                 'is_admin_project': True,
                 'service_project_domain_id': None,
                 'service_project_id': None,
-                'roles': [role],
+                'roles': roles,
                 'user_id': None,
                 'is_admin': False,
                 'service_user_domain_id': None,
@@ -704,7 +701,7 @@ class TestQuotas(base.BaseAPITest):
                 'is_admin_project': True,
                 'service_project_domain_id': None,
                 'service_project_id': None,
-                'roles': ['load-balancer_member'],
+                'roles': ['load-balancer_member', 'member'],
                 'user_id': None,
                 'is_admin': False,
                 'service_user_domain_id': None,
@@ -759,7 +756,7 @@ class TestQuotas(base.BaseAPITest):
                 'is_admin_project': True,
                 'service_project_domain_id': None,
                 'service_project_id': None,
-                'roles': ['load-balancer_quota_admin'],
+                'roles': ['admin'],
                 'user_id': None,
                 'is_admin': False,
                 'service_user_domain_id': None,
@@ -871,7 +868,7 @@ class TestQuotas(base.BaseAPITest):
                 'is_admin_project': True,
                 'service_project_domain_id': None,
                 'service_project_id': None,
-                'roles': ['load-balancer_quota_admin'],
+                'roles': ['admin'],
                 'user_id': None,
                 'is_admin': False,
                 'service_user_domain_id': None,
