@@ -37,7 +37,7 @@ class TestInterface(base.TestCase):
 
         ifaces = ('eth0', 'eth7', 'eth8')
         mock_listdir.return_value = [
-            "{}.json".format(iface)
+            f"{iface}.json"
             for iface in ifaces
         ]
         mock_listdir.return_value.extend(["invalidfile"])
@@ -48,7 +48,7 @@ class TestInterface(base.TestCase):
 
         for iface in ifaces:
             f = os.path.join(consts.AMP_NET_DIR_TEMPLATE,
-                             "{}.json".format(iface))
+                             f"{iface}.json")
             self.assertIn(f, config_file_list)
 
         # unsupported file
@@ -274,11 +274,10 @@ class TestInterface(base.TestCase):
         mock_check_output.assert_called_once_with(
             ["/sbin/dhclient",
              "-lf",
-             "/var/lib/dhclient/dhclient-{}.leases".format(
-                 iface),
+             f"/var/lib/dhclient/dhclient-{iface}.leases",
              "-pf",
-             "/run/dhclient-{}.pid".format(iface),
-             iface], stderr=-2)
+             f"/run/dhclient-{iface}.pid",
+             iface], stderr=subprocess.STDOUT)
 
     @mock.patch('subprocess.check_output')
     def test__dhclient_down(self, mock_check_output):
@@ -291,11 +290,10 @@ class TestInterface(base.TestCase):
             ["/sbin/dhclient",
              "-r",
              "-lf",
-             "/var/lib/dhclient/dhclient-{}.leases".format(
-                 iface),
+             f"/var/lib/dhclient/dhclient-{iface}.leases",
              "-pf",
-             "/run/dhclient-{}.pid".format(iface),
-             iface], stderr=-2)
+             f"/run/dhclient-{iface}.pid",
+             iface], stderr=subprocess.STDOUT)
 
     @mock.patch('subprocess.check_output')
     def test__ipv6auto_up(self, mock_check_output):
@@ -306,9 +304,11 @@ class TestInterface(base.TestCase):
 
         mock_check_output.assert_has_calls([
             mock.call(["/sbin/sysctl", "-w",
-                       "net.ipv6.conf.iface2.accept_ra=2"], stderr=-2),
+                       "net.ipv6.conf.iface2.accept_ra=2"],
+                      stderr=subprocess.STDOUT),
             mock.call(["/sbin/sysctl", "-w",
-                       "net.ipv6.conf.iface2.autoconf=1"], stderr=-2)])
+                       "net.ipv6.conf.iface2.autoconf=1"],
+                      stderr=subprocess.STDOUT)])
 
     @mock.patch('subprocess.check_output')
     def test__ipv6auto_down(self, mock_check_output):
@@ -319,9 +319,11 @@ class TestInterface(base.TestCase):
 
         mock_check_output.assert_has_calls([
             mock.call(["/sbin/sysctl", "-w",
-                       "net.ipv6.conf.iface2.accept_ra=0"], stderr=-2),
+                       "net.ipv6.conf.iface2.accept_ra=0"],
+                      stderr=subprocess.STDOUT),
             mock.call(["/sbin/sysctl", "-w",
-                       "net.ipv6.conf.iface2.autoconf=0"], stderr=-2)])
+                       "net.ipv6.conf.iface2.autoconf=0"],
+                      stderr=subprocess.STDOUT)])
 
     @mock.patch('pyroute2.IPRoute.rule')
     @mock.patch('pyroute2.IPRoute.route')
@@ -452,7 +454,7 @@ class TestInterface(base.TestCase):
     @mock.patch('octavia.amphorae.backends.utils.network_namespace.'
                 'NetworkNamespace')
     @mock.patch('octavia.amphorae.backends.utils.nftable_utils.'
-                'write_nftable_vip_rules_file')
+                'write_nftable_rules_file')
     @mock.patch('pyroute2.IPRoute.rule')
     @mock.patch('pyroute2.IPRoute.route')
     @mock.patch('pyroute2.IPRoute.addr')
@@ -578,16 +580,8 @@ class TestInterface(base.TestCase):
                       family=socket.AF_INET6)])
 
         mock_check_output.assert_has_calls([
-            mock.call([consts.NFT_CMD, consts.NFT_ADD, 'table',
-                       consts.NFT_FAMILY, consts.NFT_VIP_TABLE], stderr=-2),
-            mock.call([consts.NFT_CMD, consts.NFT_ADD, 'chain',
-                       consts.NFT_FAMILY, consts.NFT_VIP_TABLE,
-                       consts.NFT_VIP_CHAIN, '{', 'type', 'filter', 'hook',
-                       'ingress', 'device', 'fake-eth1', 'priority',
-                       consts.NFT_SRIOV_PRIORITY, ';', 'policy', 'drop', ';',
-                       '}'], stderr=-2),
-            mock.call([consts.NFT_CMD, '-o', '-f', consts.NFT_VIP_RULES_FILE],
-                      stderr=-2),
+            mock.call([consts.NFT_CMD, '-o', '-f', consts.NFT_RULES_FILE],
+                      stderr=subprocess.STDOUT),
             mock.call(["post-up", "fake-eth1"])
         ])
 
@@ -921,17 +915,16 @@ class TestInterface(base.TestCase):
         mock_check_output.assert_has_calls([
             mock.call(["/sbin/dhclient",
                        "-lf",
-                       "/var/lib/dhclient/dhclient-{}.leases".format(
-                           iface.name),
+                       f"/var/lib/dhclient/dhclient-{iface.name}.leases",
                        "-pf",
-                       "/run/dhclient-{}.pid".format(iface.name),
-                       iface.name], stderr=-2),
+                       f"/run/dhclient-{iface.name}.pid",
+                       iface.name], stderr=subprocess.STDOUT),
             mock.call(["/sbin/sysctl", "-w",
-                       "net.ipv6.conf.{}.accept_ra=2".format(iface.name)],
-                      stderr=-2),
+                       f"net.ipv6.conf.{iface.name}.accept_ra=2"],
+                      stderr=subprocess.STDOUT),
             mock.call(["/sbin/sysctl", "-w",
-                       "net.ipv6.conf.{}.autoconf=1".format(iface.name)],
-                      stderr=-2),
+                       f"net.ipv6.conf.{iface.name}.autoconf=1"],
+                      stderr=subprocess.STDOUT),
             mock.call(["post-up", iface.name])
         ])
 
@@ -1338,17 +1331,16 @@ class TestInterface(base.TestCase):
             mock.call(["/sbin/dhclient",
                        "-r",
                        "-lf",
-                       "/var/lib/dhclient/dhclient-{}.leases".format(
-                           iface.name),
+                       f"/var/lib/dhclient/dhclient-{iface.name}.leases",
                        "-pf",
-                       "/run/dhclient-{}.pid".format(iface.name),
-                       iface.name], stderr=-2),
+                       f"/run/dhclient-{iface.name}.pid",
+                       iface.name], stderr=subprocess.STDOUT),
             mock.call(["/sbin/sysctl", "-w",
-                       "net.ipv6.conf.{}.accept_ra=0".format(iface.name)],
-                      stderr=-2),
+                       f"net.ipv6.conf.{iface.name}.accept_ra=0"],
+                      stderr=subprocess.STDOUT),
             mock.call(["/sbin/sysctl", "-w",
-                       "net.ipv6.conf.{}.autoconf=0".format(iface.name)],
-                      stderr=-2),
+                       f"net.ipv6.conf.{iface.name}.autoconf=0"],
+                      stderr=subprocess.STDOUT),
             mock.call(["post-down", iface.name])
         ])
 
@@ -1444,56 +1436,3 @@ class TestInterface(base.TestCase):
 
         addr = controller._normalize_ip_network(None)
         self.assertIsNone(addr)
-
-    @mock.patch('octavia.amphorae.backends.utils.nftable_utils.'
-                'load_nftables_file')
-    @mock.patch('octavia.amphorae.backends.utils.nftable_utils.'
-                'write_nftable_vip_rules_file')
-    @mock.patch('subprocess.check_output')
-    def test__setup_nftables_chain(self, mock_check_output, mock_write_rules,
-                                   mock_load_rules):
-
-        controller = interface.InterfaceController()
-
-        mock_check_output.side_effect = [
-            mock.DEFAULT, mock.DEFAULT,
-            subprocess.CalledProcessError(cmd=consts.NFT_CMD, returncode=-1),
-            mock.DEFAULT,
-            subprocess.CalledProcessError(cmd=consts.NFT_CMD, returncode=-1)]
-
-        interface_mock = mock.MagicMock()
-        interface_mock.name = 'fake2'
-
-        # Test succeessful path
-        controller._setup_nftables_chain(interface_mock)
-
-        mock_write_rules.assert_called_once_with('fake2', [])
-        mock_load_rules.assert_called_once_with()
-        mock_check_output.assert_has_calls([
-            mock.call([consts.NFT_CMD, 'add', 'table', consts.NFT_FAMILY,
-                       consts.NFT_VIP_TABLE], stderr=subprocess.STDOUT),
-            mock.call([consts.NFT_CMD, 'add', 'chain', consts.NFT_FAMILY,
-                       consts.NFT_VIP_TABLE, consts.NFT_VIP_CHAIN, '{',
-                       'type', 'filter', 'hook', 'ingress', 'device',
-                       'fake2', 'priority', consts.NFT_SRIOV_PRIORITY, ';',
-                       'policy', 'drop', ';', '}'], stderr=subprocess.STDOUT)])
-
-        # Test first nft call fails
-        mock_write_rules.reset_mock()
-        mock_load_rules.reset_mock()
-        mock_check_output.reset_mock()
-
-        self.assertRaises(subprocess.CalledProcessError,
-                          controller._setup_nftables_chain, interface_mock)
-        mock_check_output.assert_called_once()
-        mock_write_rules.assert_not_called()
-
-        # Test second nft call fails
-        mock_write_rules.reset_mock()
-        mock_load_rules.reset_mock()
-        mock_check_output.reset_mock()
-
-        self.assertRaises(subprocess.CalledProcessError,
-                          controller._setup_nftables_chain, interface_mock)
-        self.assertEqual(2, mock_check_output.call_count)
-        mock_write_rules.assert_not_called()
